@@ -1,3 +1,4 @@
+from turtle import st
 from pydantic import BaseModel
 from typing import List, Optional
 
@@ -6,7 +7,6 @@ class Annotation(BaseModel):
     shape: str
     label_id: int
     coordinates: List[List[float]]
-    what3words: Optional[str]
     url: Optional[str]
     imagery_id: Optional[str]
     confidence: Optional[float]
@@ -21,10 +21,6 @@ class Annotation(BaseModel):
             coordinates.append([float(point[0]), float(point[1])])
 
         
-        what3words = data['what3words']
-        if what3words == "none":
-            what3words = None
-        
         imagery_id = data['imagery_id']
         if imagery_id == "NULL":
             imagery_id = None
@@ -34,7 +30,7 @@ class Annotation(BaseModel):
             confidence = None
         
         if annotation_id is None:
-            annotation_id = data['id']
+            annotation_id = int(data['id'])
 
         
         return cls(
@@ -44,8 +40,49 @@ class Annotation(BaseModel):
             label_name = data['label_name'],
             label_color = data['label_color'],
             coordinates = coordinates,
-            what3words = data['what3words'],
             url = data['url'],
             imagery_id = data['imagery_id'],
             confidence=confidence
-        )
\ No newline at end of file
+        )
+
+
+
+class Project(BaseModel):
+    name: str
+    id: str
+    user_login: str
+
+    @classmethod
+    def from_dict(cls, data: dict):
+
+        return cls(
+            name = data['name'],
+            id = data['project_id'],
+            user_login = data['user_login']
+        )
+
+class ImageryLayer(BaseModel):
+    id: str
+    project: str
+    name: str
+    url: str
+    attribution: str
+    size_mb: Optional[float]
+    bounds: Optional[List[float]]
+    min_zoom: Optional[int]
+    max_zoom: Optional[int]
+    status: Optional[str]
+
+class TilePath(BaseModel):
+    zxy: str
+    url: str
+
+
+class Task(BaseModel):
+    complete: bool
+    id: int
+    imagery_id: str
+    queue: int
+    submitter_login: Optional[str]
+    zxy: str
+
